@@ -30,6 +30,8 @@ def get_stage():
 
 class Utilities(object):
 
+    response = None
+    
     def __init__(self):
         pass
 
@@ -67,6 +69,7 @@ class Utilities(object):
         if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
             endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        Utilities.response = response
         logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
@@ -94,6 +97,7 @@ class Utilities(object):
         if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
             endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        Utilities.response = response
         logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
@@ -119,6 +123,7 @@ class Utilities(object):
         elif (endPoint.find(stagelink) != -1) and (get_stage() == 'LZ'):
             endPoint = endPoint.replace("ifi/151613", "ifi/1")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        Utilities.response = response
         logger.info(f"status code{response.status_code}")
         try:
             assert response.status_code == expectedStatusCode, \
@@ -144,6 +149,7 @@ class Utilities(object):
         if (endPoint.find(stagelink) != -1) and (get_stage() == 'beta'):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        Utilities.response = response
         logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
             "Expected and Actual status code did not match"
@@ -176,6 +182,7 @@ class Utilities(object):
         elif (endPoint.find(stagelink) != -1) and (get_stage() == 'LZ'):
             endPoint = endPoint.replace("ifi/151613", "ifi/1")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        Utilities.response = response
         logger.info(f"status code{response.status_code}")
         # logger.info("--------CURL START---------")
         # functionalParm.curl_request(response.request.url,requestMethod,headers,jsonPayload)
